summaryrefslogtreecommitdiff
path: root/src/ecommon/enum/gender.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ecommon/enum/gender.h')
-rw-r--r--src/ecommon/enum/gender.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/ecommon/enum/gender.h b/src/ecommon/enum/gender.h
index 039ca04..8c747fd 100644
--- a/src/ecommon/enum/gender.h
+++ b/src/ecommon/enum/gender.h
@@ -7,14 +7,14 @@
#include "common/mmo.h"
/**
* identical to SEX_ but also includes nonbinary
*/
typedef enum Gender
{
GENDER_FEMALE = SEX_FEMALE,
GENDER_MALE = SEX_MALE,
__UNUSED_GENDER_SERVER = SEX_SERVER,
- GENDER_NONBINARY,
+ GENDER_HIDDEN,
} Gender;
#endif // EVOL_ENUM_GENDER
@@ -7,14 +7,14 @@
#include "common/mmo.h"
/**
- * identical to SEX_ but also includes nonbinary
+ * identical to SEX_ but also includes the hidden value
*/
typedef enum Gender